#!/bin/sh

check_preinstall () {
	if [ "$HOME" = "/root" -o "$USER" = "root" ] ; then
		#echo "$HOME $USER"
		echo -n "SpRecord will be installed only for root. Do you want to continue? (y/n) [n]: "
		read T

		if [ -z "$T" -o "$T" != "y" -a "$T" != "Y" ] ; then
			return 1
		fi
	fi
	if ! [ -f ./SpRecord.exe ] ; then
		echo "Installation files not found"
		return 1
	fi
	if ! [ -x /usr/sbin/sprexsrvd ] ; then
		echo "sprecorddrv not found. Please install it before."
		return 1
	fi
	return 0
}

init_wine ()
{
	echo "Init WINE ..."
	wine ./WWC.exe
	#if ! [ -f ./wwc.dat ]; then
	#	echo "WINE initialization failed"
	#	echo "Installation failed"
	#	exit 1
	#else
	#	rm ./wwc.dat
	#fi
}

installation () {

	if [ -f ~/.sprecord/config.ini ] ; then
		if GetWINEAddr; then
			echo "Old installation found. Deinstalling it..."
			./deinstall.sh
		else
			rm ~/.sprecord/config.ini
		fi
	fi

	SS="1"

	PORT=21000

	sleep 1	
	echo
	echo -n "Do you want to open SpRecord for remote connections? (y/n) [y]: "
	read K

	if [ -z "$K" -o "$K" = "y" -o "$K" = "Y" ]; then

		echo "Enter TCP port number (21000-65535) or press \"Enter\" for use default [$PORT]:"
		read K

		if [ -n "$K" ]; then
			if ! [ "$K" -gt 20999 -a "$K" -lt 65536 ]; then
				echo "Wrong port. Please, try again and select port from 21000 to 65535."
				exit 1
			fi		
			PORT=$K
		fi

		echo "Please, wait a few minute ..."

		init_wine		

		# Import
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\$PORT" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\$PORT" /v "Port" /t REG_SZ /d "$PORT" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\$PORT" /v "ThreadCacheSize" /t REG_SZ /d "10" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\$PORT" /v "InterceptGUID" /t REG_SZ /d "" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\$PORT" /v "Timeout" /t REG_SZ /d "0" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\Settings" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\Settings" /v "ShowHost" /t REG_SZ /d "0" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\Settings" /v "RegisteredOnly" /t REG_SZ /d "1" >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKLM\\SOFTWARE\\Borland\\Socket Server\\Settings" /v "RequestPassword" /t REG_SZ /d "0" >> $EL 2>> $EL 

		SS=`more ~/.wine/system.reg | grep -e "System\\\\\\\\\\\\\\\\CurrentControlSet\\\\\\\\\\\\\\\\Services\\\\\\\\\\\\\\\\SocketServer"`

	else
		init_wine
	fi

	echo "Starting installer ..."
	wine ./SpRecord.exe
}

Log()
{
	EL="error.log"
	echo "" > $EL 
}

ShowHelp()
{
	BASE=$(basename $0)
	echo "Usage:"
	echo "$BASE        normal install"
	echo "$BASE -l     with logging"
	echo "$BASE -u     without update remote connection parameters"
}

### Installation ###

. ./include

EL="/dev/null"
TCPFIX="1"

P=$(echo $1 | tr '[A-Z]' '[a-z]')
case "$P" in
	-u)		TCPFIX="0" ;;
	-l)		Log ;;
	"")		;;
	*)		ShowHelp ;;
esac

if ! Check_commands "dirname" "sed" "awk" "mkdir" "wine" "sprecord" ; then
	echo "Installation failed"
	exit 1
fi

if ! check_preinstall; then
	echo "Installation interrupted"
	exit 1
fi
installation
if GetWINEAddr; then
	mkdir -p ~/.sprecord
	echo "INSVER=1" > ~/.sprecord/config.ini
	echo "WPATH=$WAddr" >> ~/.sprecord/config.ini

	# Register
	if [ -z "$SS" ]; then 
		wine "$WAddr\\ScktSrvr.exe" /install /silent
		sleep 1

		# Restart services
		sprecord -s
		sleep 1

		# Start SpRecord
		sprecord -f
	fi

	# fix reg parameters
	if [ "$TCPFIX" = "1" ]; then
		wine cmd /C reg ADD "HKCU\\Software\\Goofich\\SpRecord\\3.00\\rv" /v "ProtocolIndex" /t REG_DWORD /d 1 >> $EL 2>> $EL 
		wine cmd /C reg ADD "HKCU\\Software\\Goofich\\SpRecord\\3.00\\rv" /v "TCPPort" /t REG_DWORD /d 21000 >> $EL 2>> $EL 
	fi

	if [ -f "$Addr0/SpRecord.exe" ]; then
		echo "Installation successfull"
		exit 0
	fi
fi

echo "Installation failed"
exit 1

